"""Monkey patch distutils to also use setup-dev.cfg and setuptools to add README.md to the default files"""

import os
import sys
import distutils.dist
from distutils.util import (check_environ, convert_path)
from distutils.debug import DEBUG
import setuptools.command.sdist


def find_config_files(self):
    """Find as many configuration files as should be processed for this
    platform, and return a list of filenames in the order in which they
    should be parsed.  The filenames returned are guaranteed to exist
    (modulo nasty race conditions).

    There are three possible config files: distutils.cfg in the
    Distutils installation directory (ie. where the top-level
    Distutils __inst__.py file lives), a file in the user's home
    directory named .pydistutils.cfg on Unix and pydistutils.cfg
    on Windows/Mac; and setup.cfg in the current directory.

    The file in the user's home directory can be disabled with the
    --no-user-cfg option.
    """

    files = []
    check_environ()

    # Where to look for the system-wide Distutils config file
    sys_dir = os.path.dirname(sys.modules['distutils'].__file__)

    # Look for the system config file
    sys_file = os.path.join(sys_dir, "distutils.cfg")
    if os.path.isfile(sys_file):
        files.append(sys_file)

    # What to call the per-user config file
    if os.name == 'posix':
        user_filename = ".pydistutils.cfg"
    else:
        user_filename = "pydistutils.cfg"

    # And look for the user config file
    if self.want_user_cfg:
        user_file = os.path.join(os.path.expanduser('~'), user_filename)
        if os.path.isfile(user_file):
            files.append(user_file)

    # All platforms support local setup.cfg
    local_file = "setup.cfg"
    if os.path.isfile(local_file):
        files.append(local_file)

    local_dev_file = "setup-dev.cfg"
    if os.path.isfile(local_dev_file):
        files.append(local_dev_file)

    if DEBUG:
        self.announce("using config files: %s" % ', '.join(files))

    return files


def check_readme(self):
    self.READMES += ('README.md',)
    for f in self.READMES:
        if os.path.exists(f):
            return
    else:
        self.warn(
            "standard file not found: should have one of " +
            ', '.join(self.READMES)
        )


distutils.dist.Distribution.find_config_files = find_config_files
setuptools.command.sdist.sdist.check_readme = check_readme



# -*- coding: utf-8 -*-
# Test data taken from http://www.timeanddate.com/sun/uk/london

import pytz
import datetime
from astral import Astral, SUN_RISING, SUN_SETTING


def datetime_almost_equal(datetime1, datetime2, seconds=60):
    dd = datetime1 - datetime2
    sd = (dd.days * 24 * 60 * 60) + dd.seconds
    return abs(sd) <= seconds


def test_Location_GoldenHour_Morning():
    a = Astral()
    l = a['London']

    test_data = {
        datetime.date(2016, 5, 18): (datetime.datetime(2016, 5, 18, 3, 38),
                                     datetime.datetime(2016, 5, 18, 4, 53)),
        datetime.date(2016, 1, 1): (datetime.datetime(2016, 1, 1, 7, 41),
                                    datetime.datetime(2016, 1, 1, 9, 7)),
    }

    for day, golden_hour in test_data.items():
        start1 = pytz.UTC.localize(golden_hour[0])
        end1 = pytz.UTC.localize(golden_hour[1])

        start2, end2 = l.golden_hour(SUN_RISING, day)
        assert datetime_almost_equal(end1, end2, seconds=90)
        assert datetime_almost_equal(start1, start2, seconds=90)


def test_Location_GoldenHour_Evening():
    a = Astral()
    l = a['London']

    test_data = {
        datetime.date(2016, 5, 18): (datetime.datetime(2016, 5, 18, 19, 0),
                                     datetime.datetime(2016, 5, 18, 20, 16)),
    }

    for day, golden_hour in test_data.items():
        start1 = pytz.UTC.localize(golden_hour[0])
        end1 = pytz.UTC.localize(golden_hour[1])

        start2, end2 = l.golden_hour(SUN_SETTING, day)
        assert datetime_almost_equal(end1, end2, seconds=90)
        assert datetime_almost_equal(start1, start2, seconds=90)


def test_Location_BlueHour_Morning():
    a = Astral()
    l = a['London']

    test_data = {
        datetime.date(2016, 5, 19): (datetime.datetime(2016, 5, 19, 3, 19),
                                     datetime.datetime(2016, 5, 19, 3, 36)),
    }

    for day, blue_hour in test_data.items():
        start1 = pytz.UTC.localize(blue_hour[0])
        end1 = pytz.UTC.localize(blue_hour[1])

        start2, end2 = l.blue_hour(SUN_RISING, day)
        assert datetime_almost_equal(end1, end2, seconds=90)
        assert datetime_almost_equal(start1, start2, seconds=90)


def test_Location_BlueHour_Evening():
    a = Astral()
    l = a['London']

    test_data = {
        datetime.date(2016, 5, 19): (datetime.datetime(2016, 5, 19, 20, 17),
                                     datetime.datetime(2016, 5, 19, 20, 34)),
    }

    for day, blue_hour in test_data.items():
        start1 = pytz.UTC.localize(blue_hour[0])
        end1 = pytz.UTC.localize(blue_hour[1])

        start2, end2 = l.blue_hour(SUN_SETTING, day)
        assert datetime_almost_equal(end1, end2, seconds=90)
        assert datetime_almost_equal(start1, start2, seconds=90)



# -*- coding: utf-8 -*-
import pytest

import pytz
import datetime
import math
from astral import Astral

def float_almost_equal(value1, value2, diff=0.5):
    return abs(value1 - value2) <= diff


def test_ElevationPositive():
    dd = Astral()
    adjustment = dd._depression_adjustment(12000)
    assert float_almost_equal(adjustment, 1.75887208410509)


def test_ElevationNegative():
    dd = Astral()
    adjustment = dd._depression_adjustment(-1)
    assert float_almost_equal(adjustment, 0)



# Copyright 2009-2018, Simon Kennedy, sffjunkie+code@gmail.com

import io
import os
from setuptools import setup

import monkeypatch # pylint: disable=W0611

def read_contents(*names, **kwargs):
    return io.open(
        os.path.join(*names),
        encoding=kwargs.get("encoding", "utf8")
    ).read()

description = 'Calculations for the position of the sun and moon.'
try:
    long_description = read_contents(os.path.dirname(__file__), 'README.rst')
except:
    long_description = description

setup(name='astral',
    version='1.9',
    description=description,
    long_description=long_description,
    author='Simon Kennedy',
    author_email='sffjunkie+code@gmail.com',
    url="https://github.com/sffjunkie/astral",
    project_urls={
        'Documentation': 'https://astral.readthedocs.io/en/stable/index.html',
        'Source': 'https://github.com/sffjunkie/astral',
        'Issues': 'https://github.com/sffjunkie/astral/issues',
    },
    keywords="sun moon sunrise sunset dawn dusk",
    license='Apache-2.0',
    classifiers=[
    "Intended Audience :: Developers",
    "Programming Language :: Python",
    "Programming Language :: Python :: 2.7",
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: Apache Software License",
    ],
    package_dir={'': 'src'},
    py_modules=['astral'],
    install_requires=['pytz'],
    extras_require={'GoogleGeocoder': ['requests']},
    tests_require=['pytest-runner'],
    zip_safe=True,
)



import io
import os
import pytest

from astral import GoogleGeocoder

def read_contents(*names, **kwargs):
    return io.open(
        os.path.join(*names),
        encoding=kwargs.get("encoding", "utf8")
    ).read()

# 1st try to use the API_KEY environment variable that we encrypted
# in our .travis.yml
api_key = os.environ.get("API_KEY", None)
if not api_key:
	try:
	    api_key = read_contents(os.path.dirname(__file__), '.api_key').strip()
	except IOError as exc:
	    raise ValueError("Google now requires an API key to be provided")

@pytest.mark.webtest
def test_GoogleLocator_WithAPIKey():
    locator = GoogleGeocoder(api_key=api_key)
    l = locator['Eiffel Tower']
    assert l is not None
